issues

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 22, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package issues provides primitives to interact with the openapi HTTP API.

Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.8.0 DO NOT EDIT.

Index

Constants

const ServerURLHTTPSIssuesEcosysteMsAPIV1 = "https://issues.ecosyste.ms/api/v1"

ServerURLHTTPSIssuesEcosysteMsAPIV1 defines the Server URL for https://issues.ecosyste.ms/api/v1

Variables

This section is empty.

Functions

func NewCreateJobRequest

func NewCreateJobRequest(server string, body CreateJobJSONRequestBody) (*http.Request, error)

NewCreateJobRequest calls the generic CreateJob builder with application/json body

func NewCreateJobRequestWithBody

func NewCreateJobRequestWithBody(server string, contentType string, body io.Reader) (*http.Request, error)

NewCreateJobRequestWithBody constructs an http.Request for the CreateJob method, with any body, and a specified content type

func NewGetHostAuthorRequest

func NewGetHostAuthorRequest(server string, hostName string, authorName string) (*http.Request, error)

NewGetHostAuthorRequest constructs an http.Request for the GetHostAuthor method

func NewGetHostAuthorsRequest

func NewGetHostAuthorsRequest(server string, hostName string, params *GetHostAuthorsParams) (*http.Request, error)

NewGetHostAuthorsRequest constructs an http.Request for the GetHostAuthors method

func NewGetHostOwnerMaintainersRequest

func NewGetHostOwnerMaintainersRequest(server string, hostName string, ownerName string) (*http.Request, error)

NewGetHostOwnerMaintainersRequest constructs an http.Request for the GetHostOwnerMaintainers method

func NewGetHostOwnerRequest

func NewGetHostOwnerRequest(server string, hostName string, ownerName string) (*http.Request, error)

NewGetHostOwnerRequest constructs an http.Request for the GetHostOwner method

func NewGetHostOwnersRequest

func NewGetHostOwnersRequest(server string, hostName string, params *GetHostOwnersParams) (*http.Request, error)

NewGetHostOwnersRequest constructs an http.Request for the GetHostOwners method

func NewGetHostRepositoriesRequest

func NewGetHostRepositoriesRequest(server string, hostName string, params *GetHostRepositoriesParams) (*http.Request, error)

NewGetHostRepositoriesRequest constructs an http.Request for the GetHostRepositories method

func NewGetHostRepositoryIssueRequest

func NewGetHostRepositoryIssueRequest(server string, hostName string, repoName string, issueNumber int) (*http.Request, error)

NewGetHostRepositoryIssueRequest constructs an http.Request for the GetHostRepositoryIssue method

func NewGetHostRepositoryIssuesRequest

func NewGetHostRepositoryIssuesRequest(server string, hostName string, repoName string, params *GetHostRepositoryIssuesParams) (*http.Request, error)

NewGetHostRepositoryIssuesRequest constructs an http.Request for the GetHostRepositoryIssues method

func NewGetHostRepositoryLabelsRequest

func NewGetHostRepositoryLabelsRequest(server string, hostName string, repoName string) (*http.Request, error)

NewGetHostRepositoryLabelsRequest constructs an http.Request for the GetHostRepositoryLabels method

func NewGetHostRepositoryRequest

func NewGetHostRepositoryRequest(server string, hostName string, repoName string) (*http.Request, error)

NewGetHostRepositoryRequest constructs an http.Request for the GetHostRepository method

func NewGetHostRequest

func NewGetHostRequest(server string, hostName string) (*http.Request, error)

NewGetHostRequest constructs an http.Request for the GetHost method

func NewGetHostsRequest added in v0.4.0

func NewGetHostsRequest(server string, params *GetHostsParams) (*http.Request, error)

NewGetHostsRequest constructs an http.Request for the GetHosts method

func NewGetJobRequest

func NewGetJobRequest(server string, jobID int) (*http.Request, error)

NewGetJobRequest constructs an http.Request for the GetJob method

func NewRepositoriesLookupRequest

func NewRepositoriesLookupRequest(server string, params *RepositoriesLookupParams) (*http.Request, error)

NewRepositoriesLookupRequest constructs an http.Request for the RepositoriesLookup method

Types

type Author

type Author struct {
	ActiveMaintaining                  []RepoCount              `json:"active_maintaining,omitempty"`
	AverageIssueCloseTime              *float32                 `json:"average_issue_close_time,omitempty"`
	AverageIssueCommentsCount          *float32                 `json:"average_issue_comments_count,omitempty"`
	AveragePullRequestCloseTime        *float32                 `json:"average_pull_request_close_time,omitempty"`
	AveragePullRequestCommentsCount    *float32                 `json:"average_pull_request_comments_count,omitempty"`
	IssueAuthorAssociationsCount       []AuthorAssociationCount `json:"issue_author_associations_count,omitempty"`
	IssueLabelsCount                   []LabelCount             `json:"issue_labels_count,omitempty"`
	IssueRepos                         []RepoCount              `json:"issue_repos,omitempty"`
	IssuesCount                        *int                     `json:"issues_count,omitempty"`
	Login                              *string                  `json:"login,omitempty"`
	Maintaining                        []RepoCount              `json:"maintaining,omitempty"`
	MergedPullRequestsCount            *int                     `json:"merged_pull_requests_count,omitempty"`
	PullRequestAuthorAssociationsCount []AuthorAssociationCount `json:"pull_request_author_associations_count,omitempty"`
	PullRequestLabelsCount             []LabelCount             `json:"pull_request_labels_count,omitempty"`
	PullRequestRepos                   []RepoCount              `json:"pull_request_repos,omitempty"`
	PullRequestsCount                  *int                     `json:"pull_requests_count,omitempty"`
}

Author defines model for Author.

type AuthorAssociationCount

type AuthorAssociationCount struct {
	AuthorAssociation *string `json:"author_association,omitempty"`
	Count             *int    `json:"count,omitempty"`
}

AuthorAssociationCount defines model for AuthorAssociationCount.

type AuthorCount

type AuthorCount struct {
	Author *string `json:"author,omitempty"`
	Count  *int    `json:"count,omitempty"`
	URL    *string `json:"url,omitempty"`
}

AuthorCount defines model for AuthorCount.

type AuthorSummary

type AuthorSummary struct {
	AuthorURL         *string `json:"author_url,omitempty"`
	Login             *string `json:"login,omitempty"`
	RepositoriesCount *int    `json:"repositories_count,omitempty"`
}

AuthorSummary defines model for AuthorSummary.

type Client

type Client struct {
	// The endpoint of the server conforming to this interface, with scheme,
	// https://api.deepmap.com for example. This can contain a path relative
	// to the server, such as https://api.deepmap.com/dev-test, and all the
	// paths in the swagger spec will be appended to the server.
	Server string

	// Doer for performing requests, typically a *http.Client with any
	// customized settings, such as certificate chains.
	Client HttpRequestDoer

	// A list of callbacks for modifying requests which are generated before sending over
	// the network.
	RequestEditors []RequestEditorFn
}

Client which conforms to the OpenAPI3 specification for this service.

func NewClient

func NewClient(server string, opts ...ClientOption) (*Client, error)

Creates a new Client, with reasonable defaults

func (*Client) CreateJob

func (c *Client) CreateJob(ctx context.Context, body CreateJobJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

CreateJob create a job to sync issues from a URL

Takes a body of the `application/json` content type.

Corresponds with POST /jobs (the `CreateJob` operationId).

func (*Client) CreateJobWithBody

func (c *Client) CreateJobWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

CreateJobWithBody create a job to sync issues from a URL

Takes any type of body and a specified content type.

Corresponds with POST /jobs (the `CreateJob` operationId).

func (*Client) GetHost

func (c *Client) GetHost(ctx context.Context, hostName string, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHost get a host by name

Corresponds with GET /hosts/{hostName} (the `GetHost` operationId).

func (*Client) GetHostAuthor

func (c *Client) GetHostAuthor(ctx context.Context, hostName string, authorName string, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHostAuthor get author statistics from a host

Corresponds with GET /hosts/{hostName}/authors/{authorName} (the `GetHostAuthor` operationId).

func (*Client) GetHostAuthors

func (c *Client) GetHostAuthors(ctx context.Context, hostName string, params *GetHostAuthorsParams, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHostAuthors get a list of authors from a host

Corresponds with GET /hosts/{hostName}/authors (the `GetHostAuthors` operationId).

func (*Client) GetHostOwner

func (c *Client) GetHostOwner(ctx context.Context, hostName string, ownerName string, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHostOwner get owner statistics from a host

Corresponds with GET /hosts/{hostName}/owners/{ownerName} (the `GetHostOwner` operationId).

func (*Client) GetHostOwnerMaintainers

func (c *Client) GetHostOwnerMaintainers(ctx context.Context, hostName string, ownerName string, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHostOwnerMaintainers get maintainers for an owner

Corresponds with GET /hosts/{hostName}/owners/{ownerName}/maintainers (the `GetHostOwnerMaintainers` operationId).

func (*Client) GetHostOwners

func (c *Client) GetHostOwners(ctx context.Context, hostName string, params *GetHostOwnersParams, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHostOwners get a list of owners from a host

Corresponds with GET /hosts/{hostName}/owners (the `GetHostOwners` operationId).

func (*Client) GetHostRepositories

func (c *Client) GetHostRepositories(ctx context.Context, hostName string, params *GetHostRepositoriesParams, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHostRepositories get a list of repositories from a host

Corresponds with GET /hosts/{hostName}/repositories (the `GetHostRepositories` operationId).

func (*Client) GetHostRepository

func (c *Client) GetHostRepository(ctx context.Context, hostName string, repoName string, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHostRepository get a repository from a host

Corresponds with GET /hosts/{hostName}/repositories/{repoName} (the `GetHostRepository` operationId).

func (*Client) GetHostRepositoryIssue

func (c *Client) GetHostRepositoryIssue(ctx context.Context, hostName string, repoName string, issueNumber int, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHostRepositoryIssue get an issue from a repository

Corresponds with GET /hosts/{hostName}/repositories/{repoName}/issues/{issueNumber} (the `GetHostRepositoryIssue` operationId).

func (*Client) GetHostRepositoryIssues

func (c *Client) GetHostRepositoryIssues(ctx context.Context, hostName string, repoName string, params *GetHostRepositoryIssuesParams, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHostRepositoryIssues get a list of issues from a repository

Corresponds with GET /hosts/{hostName}/repositories/{repoName}/issues (the `GetHostRepositoryIssues` operationId).

func (*Client) GetHostRepositoryLabels

func (c *Client) GetHostRepositoryLabels(ctx context.Context, hostName string, repoName string, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHostRepositoryLabels get a list of labels used in issues for a repository

Corresponds with GET /hosts/{hostName}/repositories/{repoName}/labels (the `GetHostRepositoryLabels` operationId).

func (*Client) GetHosts added in v0.4.0

func (c *Client) GetHosts(ctx context.Context, params *GetHostsParams, reqEditors ...RequestEditorFn) (*http.Response, error)

GetHosts list hosts

Corresponds with GET /hosts (the `GetHosts` operationId).

func (*Client) GetJob

func (c *Client) GetJob(ctx context.Context, jobID int, reqEditors ...RequestEditorFn) (*http.Response, error)

GetJob get the status of a job

Corresponds with GET /jobs/{jobId} (the `GetJob` operationId).

func (*Client) RepositoriesLookup

func (c *Client) RepositoriesLookup(ctx context.Context, params *RepositoriesLookupParams, reqEditors ...RequestEditorFn) (*http.Response, error)

RepositoriesLookup Lookup repository metadata

Corresponds with GET /repositories/lookup (the `RepositoriesLookup` operationId).

type ClientInterface

type ClientInterface interface {

	// GetHosts list hosts
	//
	// Corresponds with GET /hosts (the `GetHosts` operationId).
	GetHosts(ctx context.Context, params *GetHostsParams, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetHost get a host by name
	//
	// Corresponds with GET /hosts/{hostName} (the `GetHost` operationId).
	GetHost(ctx context.Context, hostName string, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetHostAuthors get a list of authors from a host
	//
	// Corresponds with GET /hosts/{hostName}/authors (the `GetHostAuthors` operationId).
	GetHostAuthors(ctx context.Context, hostName string, params *GetHostAuthorsParams, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetHostAuthor get author statistics from a host
	//
	// Corresponds with GET /hosts/{hostName}/authors/{authorName} (the `GetHostAuthor` operationId).
	GetHostAuthor(ctx context.Context, hostName string, authorName string, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetHostOwners get a list of owners from a host
	//
	// Corresponds with GET /hosts/{hostName}/owners (the `GetHostOwners` operationId).
	GetHostOwners(ctx context.Context, hostName string, params *GetHostOwnersParams, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetHostOwner get owner statistics from a host
	//
	// Corresponds with GET /hosts/{hostName}/owners/{ownerName} (the `GetHostOwner` operationId).
	GetHostOwner(ctx context.Context, hostName string, ownerName string, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetHostOwnerMaintainers get maintainers for an owner
	//
	// Corresponds with GET /hosts/{hostName}/owners/{ownerName}/maintainers (the `GetHostOwnerMaintainers` operationId).
	GetHostOwnerMaintainers(ctx context.Context, hostName string, ownerName string, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetHostRepositories get a list of repositories from a host
	//
	// Corresponds with GET /hosts/{hostName}/repositories (the `GetHostRepositories` operationId).
	GetHostRepositories(ctx context.Context, hostName string, params *GetHostRepositoriesParams, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetHostRepository get a repository from a host
	//
	// Corresponds with GET /hosts/{hostName}/repositories/{repoName} (the `GetHostRepository` operationId).
	GetHostRepository(ctx context.Context, hostName string, repoName string, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetHostRepositoryIssues get a list of issues from a repository
	//
	// Corresponds with GET /hosts/{hostName}/repositories/{repoName}/issues (the `GetHostRepositoryIssues` operationId).
	GetHostRepositoryIssues(ctx context.Context, hostName string, repoName string, params *GetHostRepositoryIssuesParams, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetHostRepositoryIssue get an issue from a repository
	//
	// Corresponds with GET /hosts/{hostName}/repositories/{repoName}/issues/{issueNumber} (the `GetHostRepositoryIssue` operationId).
	GetHostRepositoryIssue(ctx context.Context, hostName string, repoName string, issueNumber int, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetHostRepositoryLabels get a list of labels used in issues for a repository
	//
	// Corresponds with GET /hosts/{hostName}/repositories/{repoName}/labels (the `GetHostRepositoryLabels` operationId).
	GetHostRepositoryLabels(ctx context.Context, hostName string, repoName string, reqEditors ...RequestEditorFn) (*http.Response, error)

	// CreateJobWithBody create a job to sync issues from a URL
	//
	// Takes any type of body and a specified content type.
	//
	// Corresponds with POST /jobs (the `CreateJob` operationId).
	CreateJobWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

	// CreateJob create a job to sync issues from a URL
	//
	// Takes a body of the `application/json` content type.
	//
	// Corresponds with POST /jobs (the `CreateJob` operationId).
	CreateJob(ctx context.Context, body CreateJobJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetJob get the status of a job
	//
	// Corresponds with GET /jobs/{jobId} (the `GetJob` operationId).
	GetJob(ctx context.Context, jobID int, reqEditors ...RequestEditorFn) (*http.Response, error)

	// RepositoriesLookup Lookup repository metadata
	//
	// Corresponds with GET /repositories/lookup (the `RepositoriesLookup` operationId).
	RepositoriesLookup(ctx context.Context, params *RepositoriesLookupParams, reqEditors ...RequestEditorFn) (*http.Response, error)
}

The interface specification for the client above.

type ClientOption

type ClientOption func(*Client) error

ClientOption allows setting custom parameters during construction

func WithBaseURL

func WithBaseURL(baseURL string) ClientOption

WithBaseURL overrides the baseURL.

func WithHTTPClient

func WithHTTPClient(doer HttpRequestDoer) ClientOption

WithHTTPClient allows overriding the default Doer, which is automatically created using http.Client. This is useful for tests.

func WithRequestEditorFn

func WithRequestEditorFn(fn RequestEditorFn) ClientOption

WithRequestEditorFn allows setting up a callback function, which will be called right before sending the request. This can be used to mutate the request.

type ClientWithResponses

type ClientWithResponses struct {
	ClientInterface
}

ClientWithResponses builds on ClientInterface to offer response payloads

func NewClientWithResponses

func NewClientWithResponses(server string, opts ...ClientOption) (*ClientWithResponses, error)

NewClientWithResponses creates a new ClientWithResponses, which wraps Client with return type handling

func (*ClientWithResponses) CreateJobWithBodyWithResponse

func (c *ClientWithResponses) CreateJobWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateJobResponse, error)

CreateJobWithBodyWithResponse create a job to sync issues from a URL

Takes any type of body and a specified content type, and returns a wrapper object for the known response body format(s).

Corresponds with POST /jobs (the `CreateJob` operationId).

func (*ClientWithResponses) CreateJobWithResponse

func (c *ClientWithResponses) CreateJobWithResponse(ctx context.Context, body CreateJobJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateJobResponse, error)

CreateJobWithResponse create a job to sync issues from a URL

Takes a body of the `application/json` content type, and returns a wrapper object for the known response body format(s).

Corresponds with POST /jobs (the `CreateJob` operationId).

func (*ClientWithResponses) GetHostAuthorWithResponse

func (c *ClientWithResponses) GetHostAuthorWithResponse(ctx context.Context, hostName string, authorName string, reqEditors ...RequestEditorFn) (*GetHostAuthorResponse, error)

GetHostAuthorWithResponse get author statistics from a host

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts/{hostName}/authors/{authorName} (the `GetHostAuthor` operationId).

func (*ClientWithResponses) GetHostAuthorsWithResponse

func (c *ClientWithResponses) GetHostAuthorsWithResponse(ctx context.Context, hostName string, params *GetHostAuthorsParams, reqEditors ...RequestEditorFn) (*GetHostAuthorsResponse, error)

GetHostAuthorsWithResponse get a list of authors from a host

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts/{hostName}/authors (the `GetHostAuthors` operationId).

func (*ClientWithResponses) GetHostOwnerMaintainersWithResponse

func (c *ClientWithResponses) GetHostOwnerMaintainersWithResponse(ctx context.Context, hostName string, ownerName string, reqEditors ...RequestEditorFn) (*GetHostOwnerMaintainersResponse, error)

GetHostOwnerMaintainersWithResponse get maintainers for an owner

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts/{hostName}/owners/{ownerName}/maintainers (the `GetHostOwnerMaintainers` operationId).

func (*ClientWithResponses) GetHostOwnerWithResponse

func (c *ClientWithResponses) GetHostOwnerWithResponse(ctx context.Context, hostName string, ownerName string, reqEditors ...RequestEditorFn) (*GetHostOwnerResponse, error)

GetHostOwnerWithResponse get owner statistics from a host

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts/{hostName}/owners/{ownerName} (the `GetHostOwner` operationId).

func (*ClientWithResponses) GetHostOwnersWithResponse

func (c *ClientWithResponses) GetHostOwnersWithResponse(ctx context.Context, hostName string, params *GetHostOwnersParams, reqEditors ...RequestEditorFn) (*GetHostOwnersResponse, error)

GetHostOwnersWithResponse get a list of owners from a host

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts/{hostName}/owners (the `GetHostOwners` operationId).

func (*ClientWithResponses) GetHostRepositoriesWithResponse

func (c *ClientWithResponses) GetHostRepositoriesWithResponse(ctx context.Context, hostName string, params *GetHostRepositoriesParams, reqEditors ...RequestEditorFn) (*GetHostRepositoriesResponse, error)

GetHostRepositoriesWithResponse get a list of repositories from a host

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts/{hostName}/repositories (the `GetHostRepositories` operationId).

func (*ClientWithResponses) GetHostRepositoryIssueWithResponse

func (c *ClientWithResponses) GetHostRepositoryIssueWithResponse(ctx context.Context, hostName string, repoName string, issueNumber int, reqEditors ...RequestEditorFn) (*GetHostRepositoryIssueResponse, error)

GetHostRepositoryIssueWithResponse get an issue from a repository

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts/{hostName}/repositories/{repoName}/issues/{issueNumber} (the `GetHostRepositoryIssue` operationId).

func (*ClientWithResponses) GetHostRepositoryIssuesWithResponse

func (c *ClientWithResponses) GetHostRepositoryIssuesWithResponse(ctx context.Context, hostName string, repoName string, params *GetHostRepositoryIssuesParams, reqEditors ...RequestEditorFn) (*GetHostRepositoryIssuesResponse, error)

GetHostRepositoryIssuesWithResponse get a list of issues from a repository

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts/{hostName}/repositories/{repoName}/issues (the `GetHostRepositoryIssues` operationId).

func (*ClientWithResponses) GetHostRepositoryLabelsWithResponse

func (c *ClientWithResponses) GetHostRepositoryLabelsWithResponse(ctx context.Context, hostName string, repoName string, reqEditors ...RequestEditorFn) (*GetHostRepositoryLabelsResponse, error)

GetHostRepositoryLabelsWithResponse get a list of labels used in issues for a repository

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts/{hostName}/repositories/{repoName}/labels (the `GetHostRepositoryLabels` operationId).

func (*ClientWithResponses) GetHostRepositoryWithResponse

func (c *ClientWithResponses) GetHostRepositoryWithResponse(ctx context.Context, hostName string, repoName string, reqEditors ...RequestEditorFn) (*GetHostRepositoryResponse, error)

GetHostRepositoryWithResponse get a repository from a host

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts/{hostName}/repositories/{repoName} (the `GetHostRepository` operationId).

func (*ClientWithResponses) GetHostWithResponse

func (c *ClientWithResponses) GetHostWithResponse(ctx context.Context, hostName string, reqEditors ...RequestEditorFn) (*GetHostResponse, error)

GetHostWithResponse get a host by name

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts/{hostName} (the `GetHost` operationId).

func (*ClientWithResponses) GetHostsWithResponse added in v0.4.0

func (c *ClientWithResponses) GetHostsWithResponse(ctx context.Context, params *GetHostsParams, reqEditors ...RequestEditorFn) (*GetHostsResponse, error)

GetHostsWithResponse list hosts

Returns a wrapper object for the known response body format(s).

Corresponds with GET /hosts (the `GetHosts` operationId).

func (*ClientWithResponses) GetJobWithResponse

func (c *ClientWithResponses) GetJobWithResponse(ctx context.Context, jobID int, reqEditors ...RequestEditorFn) (*GetJobResponse, error)

GetJobWithResponse get the status of a job

Returns a wrapper object for the known response body format(s).

Corresponds with GET /jobs/{jobId} (the `GetJob` operationId).

func (*ClientWithResponses) RepositoriesLookupWithResponse

func (c *ClientWithResponses) RepositoriesLookupWithResponse(ctx context.Context, params *RepositoriesLookupParams, reqEditors ...RequestEditorFn) (*RepositoriesLookupResponse, error)

RepositoriesLookupWithResponse Lookup repository metadata

Returns a wrapper object for the known response body format(s).

Corresponds with GET /repositories/lookup (the `RepositoriesLookup` operationId).

type ClientWithResponsesInterface

type ClientWithResponsesInterface interface {

	// GetHostsWithResponse list hosts
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts (the `GetHosts` operationId).
	GetHostsWithResponse(ctx context.Context, params *GetHostsParams, reqEditors ...RequestEditorFn) (*GetHostsResponse, error)

	// GetHostWithResponse get a host by name
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts/{hostName} (the `GetHost` operationId).
	GetHostWithResponse(ctx context.Context, hostName string, reqEditors ...RequestEditorFn) (*GetHostResponse, error)

	// GetHostAuthorsWithResponse get a list of authors from a host
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts/{hostName}/authors (the `GetHostAuthors` operationId).
	GetHostAuthorsWithResponse(ctx context.Context, hostName string, params *GetHostAuthorsParams, reqEditors ...RequestEditorFn) (*GetHostAuthorsResponse, error)

	// GetHostAuthorWithResponse get author statistics from a host
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts/{hostName}/authors/{authorName} (the `GetHostAuthor` operationId).
	GetHostAuthorWithResponse(ctx context.Context, hostName string, authorName string, reqEditors ...RequestEditorFn) (*GetHostAuthorResponse, error)

	// GetHostOwnersWithResponse get a list of owners from a host
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts/{hostName}/owners (the `GetHostOwners` operationId).
	GetHostOwnersWithResponse(ctx context.Context, hostName string, params *GetHostOwnersParams, reqEditors ...RequestEditorFn) (*GetHostOwnersResponse, error)

	// GetHostOwnerWithResponse get owner statistics from a host
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts/{hostName}/owners/{ownerName} (the `GetHostOwner` operationId).
	GetHostOwnerWithResponse(ctx context.Context, hostName string, ownerName string, reqEditors ...RequestEditorFn) (*GetHostOwnerResponse, error)

	// GetHostOwnerMaintainersWithResponse get maintainers for an owner
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts/{hostName}/owners/{ownerName}/maintainers (the `GetHostOwnerMaintainers` operationId).
	GetHostOwnerMaintainersWithResponse(ctx context.Context, hostName string, ownerName string, reqEditors ...RequestEditorFn) (*GetHostOwnerMaintainersResponse, error)

	// GetHostRepositoriesWithResponse get a list of repositories from a host
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts/{hostName}/repositories (the `GetHostRepositories` operationId).
	GetHostRepositoriesWithResponse(ctx context.Context, hostName string, params *GetHostRepositoriesParams, reqEditors ...RequestEditorFn) (*GetHostRepositoriesResponse, error)

	// GetHostRepositoryWithResponse get a repository from a host
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts/{hostName}/repositories/{repoName} (the `GetHostRepository` operationId).
	GetHostRepositoryWithResponse(ctx context.Context, hostName string, repoName string, reqEditors ...RequestEditorFn) (*GetHostRepositoryResponse, error)

	// GetHostRepositoryIssuesWithResponse get a list of issues from a repository
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts/{hostName}/repositories/{repoName}/issues (the `GetHostRepositoryIssues` operationId).
	GetHostRepositoryIssuesWithResponse(ctx context.Context, hostName string, repoName string, params *GetHostRepositoryIssuesParams, reqEditors ...RequestEditorFn) (*GetHostRepositoryIssuesResponse, error)

	// GetHostRepositoryIssueWithResponse get an issue from a repository
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts/{hostName}/repositories/{repoName}/issues/{issueNumber} (the `GetHostRepositoryIssue` operationId).
	GetHostRepositoryIssueWithResponse(ctx context.Context, hostName string, repoName string, issueNumber int, reqEditors ...RequestEditorFn) (*GetHostRepositoryIssueResponse, error)

	// GetHostRepositoryLabelsWithResponse get a list of labels used in issues for a repository
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /hosts/{hostName}/repositories/{repoName}/labels (the `GetHostRepositoryLabels` operationId).
	GetHostRepositoryLabelsWithResponse(ctx context.Context, hostName string, repoName string, reqEditors ...RequestEditorFn) (*GetHostRepositoryLabelsResponse, error)

	// CreateJobWithBodyWithResponse create a job to sync issues from a URL
	//
	// Takes any type of body and a specified content type, and returns a wrapper object for the known response body format(s).
	//
	// Corresponds with POST /jobs (the `CreateJob` operationId).
	CreateJobWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateJobResponse, error)

	// CreateJobWithResponse create a job to sync issues from a URL
	//
	// Takes a body of the `application/json` content type, and returns a wrapper object for the known response body format(s).
	//
	// Corresponds with POST /jobs (the `CreateJob` operationId).
	CreateJobWithResponse(ctx context.Context, body CreateJobJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateJobResponse, error)

	// GetJobWithResponse get the status of a job
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /jobs/{jobId} (the `GetJob` operationId).
	GetJobWithResponse(ctx context.Context, jobID int, reqEditors ...RequestEditorFn) (*GetJobResponse, error)

	// RepositoriesLookupWithResponse Lookup repository metadata
	//
	// Returns a wrapper object for the known response body format(s).
	//
	// Corresponds with GET /repositories/lookup (the `RepositoriesLookup` operationId).
	RepositoriesLookupWithResponse(ctx context.Context, params *RepositoriesLookupParams, reqEditors ...RequestEditorFn) (*RepositoriesLookupResponse, error)
}

ClientWithResponsesInterface is the interface specification for the client with responses above.

type CreateJob400JSONResponseBody added in v0.4.0

type CreateJob400JSONResponseBody struct {
	Details []string `json:"details,omitempty"`
	Title   *string  `json:"title,omitempty"`
}

CreateJob400JSONResponseBody defines parameters for CreateJob.

type CreateJobJSONBody

type CreateJobJSONBody struct {
	// URL URL of the repository to sync issues from
	URL string `json:"url"`
}

CreateJobJSONBody defines parameters for CreateJob.

type CreateJobJSONRequestBody

type CreateJobJSONRequestBody CreateJobJSONBody

CreateJobJSONRequestBody defines body for CreateJob for application/json ContentType.

type CreateJobResponse

type CreateJobResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON400 the response for an HTTP 400 `application/json` response
	JSON400 *CreateJob400JSONResponseBody
}

func ParseCreateJobResponse

func ParseCreateJobResponse(rsp *http.Response) (*CreateJobResponse, error)

ParseCreateJobResponse parses an HTTP response from a CreateJobWithResponse call

func (CreateJobResponse) ContentType added in v0.4.0

func (r CreateJobResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (CreateJobResponse) Status

func (r CreateJobResponse) Status() string

Status returns HTTPResponse.Status

func (CreateJobResponse) StatusCode

func (r CreateJobResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostAuthorResponse

type GetHostAuthorResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *Author
}

func ParseGetHostAuthorResponse

func ParseGetHostAuthorResponse(rsp *http.Response) (*GetHostAuthorResponse, error)

ParseGetHostAuthorResponse parses an HTTP response from a GetHostAuthorWithResponse call

func (GetHostAuthorResponse) ContentType added in v0.4.0

func (r GetHostAuthorResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostAuthorResponse) Status

func (r GetHostAuthorResponse) Status() string

Status returns HTTPResponse.Status

func (GetHostAuthorResponse) StatusCode

func (r GetHostAuthorResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostAuthorsParams

type GetHostAuthorsParams struct {
	// Page pagination page number
	Page *int `form:"page,omitempty" json:"page,omitempty"`

	// PerPage Number of records to return
	PerPage *int `form:"per_page,omitempty" json:"per_page,omitempty"`
}

GetHostAuthorsParams defines parameters for GetHostAuthors.

type GetHostAuthorsResponse

type GetHostAuthorsResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *[]AuthorSummary
}

func ParseGetHostAuthorsResponse

func ParseGetHostAuthorsResponse(rsp *http.Response) (*GetHostAuthorsResponse, error)

ParseGetHostAuthorsResponse parses an HTTP response from a GetHostAuthorsWithResponse call

func (GetHostAuthorsResponse) ContentType added in v0.4.0

func (r GetHostAuthorsResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostAuthorsResponse) Status

func (r GetHostAuthorsResponse) Status() string

Status returns HTTPResponse.Status

func (GetHostAuthorsResponse) StatusCode

func (r GetHostAuthorsResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostOwnerMaintainersResponse

type GetHostOwnerMaintainersResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *Maintainers
}

func ParseGetHostOwnerMaintainersResponse

func ParseGetHostOwnerMaintainersResponse(rsp *http.Response) (*GetHostOwnerMaintainersResponse, error)

ParseGetHostOwnerMaintainersResponse parses an HTTP response from a GetHostOwnerMaintainersWithResponse call

func (GetHostOwnerMaintainersResponse) ContentType added in v0.4.0

func (r GetHostOwnerMaintainersResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostOwnerMaintainersResponse) Status

Status returns HTTPResponse.Status

func (GetHostOwnerMaintainersResponse) StatusCode

func (r GetHostOwnerMaintainersResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostOwnerResponse

type GetHostOwnerResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *Owner
}

func ParseGetHostOwnerResponse

func ParseGetHostOwnerResponse(rsp *http.Response) (*GetHostOwnerResponse, error)

ParseGetHostOwnerResponse parses an HTTP response from a GetHostOwnerWithResponse call

func (GetHostOwnerResponse) ContentType added in v0.4.0

func (r GetHostOwnerResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostOwnerResponse) Status

func (r GetHostOwnerResponse) Status() string

Status returns HTTPResponse.Status

func (GetHostOwnerResponse) StatusCode

func (r GetHostOwnerResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostOwnersParams

type GetHostOwnersParams struct {
	// Page pagination page number
	Page *int `form:"page,omitempty" json:"page,omitempty"`

	// PerPage Number of records to return
	PerPage *int `form:"per_page,omitempty" json:"per_page,omitempty"`
}

GetHostOwnersParams defines parameters for GetHostOwners.

type GetHostOwnersResponse

type GetHostOwnersResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *[]OwnerSummary
}

func ParseGetHostOwnersResponse

func ParseGetHostOwnersResponse(rsp *http.Response) (*GetHostOwnersResponse, error)

ParseGetHostOwnersResponse parses an HTTP response from a GetHostOwnersWithResponse call

func (GetHostOwnersResponse) ContentType added in v0.4.0

func (r GetHostOwnersResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostOwnersResponse) Status

func (r GetHostOwnersResponse) Status() string

Status returns HTTPResponse.Status

func (GetHostOwnersResponse) StatusCode

func (r GetHostOwnersResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostRepositoriesParams

type GetHostRepositoriesParams struct {
	// Page pagination page number
	Page *int `form:"page,omitempty" json:"page,omitempty"`

	// PerPage Number of records to return
	PerPage *int `form:"per_page,omitempty" json:"per_page,omitempty"`

	// CreatedAfter filter by created_at after given time
	CreatedAfter *time.Time `form:"created_after,omitempty" json:"created_after,omitempty"`

	// UpdatedAfter filter by updated_at after given time
	UpdatedAfter *time.Time `form:"updated_after,omitempty" json:"updated_after,omitempty"`

	// Sort field to order results by
	Sort *string `form:"sort,omitempty" json:"sort,omitempty"`

	// Order direction to order results by
	Order *string `form:"order,omitempty" json:"order,omitempty"`
}

GetHostRepositoriesParams defines parameters for GetHostRepositories.

type GetHostRepositoriesResponse

type GetHostRepositoriesResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *[]Repository
}

func ParseGetHostRepositoriesResponse

func ParseGetHostRepositoriesResponse(rsp *http.Response) (*GetHostRepositoriesResponse, error)

ParseGetHostRepositoriesResponse parses an HTTP response from a GetHostRepositoriesWithResponse call

func (GetHostRepositoriesResponse) ContentType added in v0.4.0

func (r GetHostRepositoriesResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostRepositoriesResponse) Status

Status returns HTTPResponse.Status

func (GetHostRepositoriesResponse) StatusCode

func (r GetHostRepositoriesResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostRepositoryIssueResponse

type GetHostRepositoryIssueResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *Issue
}

func ParseGetHostRepositoryIssueResponse

func ParseGetHostRepositoryIssueResponse(rsp *http.Response) (*GetHostRepositoryIssueResponse, error)

ParseGetHostRepositoryIssueResponse parses an HTTP response from a GetHostRepositoryIssueWithResponse call

func (GetHostRepositoryIssueResponse) ContentType added in v0.4.0

func (r GetHostRepositoryIssueResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostRepositoryIssueResponse) Status

Status returns HTTPResponse.Status

func (GetHostRepositoryIssueResponse) StatusCode

func (r GetHostRepositoryIssueResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostRepositoryIssuesParams

type GetHostRepositoryIssuesParams struct {
	// Page pagination page number
	Page *int `form:"page,omitempty" json:"page,omitempty"`

	// PerPage Number of records to return
	PerPage *int `form:"per_page,omitempty" json:"per_page,omitempty"`

	// CreatedAfter filter by created_at after given time
	CreatedAfter *time.Time `form:"created_after,omitempty" json:"created_after,omitempty"`

	// UpdatedAfter filter by updated_at after given time
	UpdatedAfter *time.Time `form:"updated_after,omitempty" json:"updated_after,omitempty"`

	// Sort field to order results by
	Sort *string `form:"sort,omitempty" json:"sort,omitempty"`

	// Order direction to order results by
	Order *string `form:"order,omitempty" json:"order,omitempty"`

	// PullRequest filter by if it's a pull request
	PullRequest *bool `form:"pull_request,omitempty" json:"pull_request,omitempty"`

	// State filter by issue state (open, closed)
	State *string `form:"state,omitempty" json:"state,omitempty"`

	// Label filter by label name
	Label *string `form:"label,omitempty" json:"label,omitempty"`
}

GetHostRepositoryIssuesParams defines parameters for GetHostRepositoryIssues.

type GetHostRepositoryIssuesResponse

type GetHostRepositoryIssuesResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *[]Issue
}

func ParseGetHostRepositoryIssuesResponse

func ParseGetHostRepositoryIssuesResponse(rsp *http.Response) (*GetHostRepositoryIssuesResponse, error)

ParseGetHostRepositoryIssuesResponse parses an HTTP response from a GetHostRepositoryIssuesWithResponse call

func (GetHostRepositoryIssuesResponse) ContentType added in v0.4.0

func (r GetHostRepositoryIssuesResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostRepositoryIssuesResponse) Status

Status returns HTTPResponse.Status

func (GetHostRepositoryIssuesResponse) StatusCode

func (r GetHostRepositoryIssuesResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostRepositoryLabelsResponse

type GetHostRepositoryLabelsResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *[]LabelCount
}

func ParseGetHostRepositoryLabelsResponse

func ParseGetHostRepositoryLabelsResponse(rsp *http.Response) (*GetHostRepositoryLabelsResponse, error)

ParseGetHostRepositoryLabelsResponse parses an HTTP response from a GetHostRepositoryLabelsWithResponse call

func (GetHostRepositoryLabelsResponse) ContentType added in v0.4.0

func (r GetHostRepositoryLabelsResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostRepositoryLabelsResponse) Status

Status returns HTTPResponse.Status

func (GetHostRepositoryLabelsResponse) StatusCode

func (r GetHostRepositoryLabelsResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostRepositoryResponse

type GetHostRepositoryResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *Repository
}

func ParseGetHostRepositoryResponse

func ParseGetHostRepositoryResponse(rsp *http.Response) (*GetHostRepositoryResponse, error)

ParseGetHostRepositoryResponse parses an HTTP response from a GetHostRepositoryWithResponse call

func (GetHostRepositoryResponse) ContentType added in v0.4.0

func (r GetHostRepositoryResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostRepositoryResponse) Status

func (r GetHostRepositoryResponse) Status() string

Status returns HTTPResponse.Status

func (GetHostRepositoryResponse) StatusCode

func (r GetHostRepositoryResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostResponse

type GetHostResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *Host
}

func ParseGetHostResponse

func ParseGetHostResponse(rsp *http.Response) (*GetHostResponse, error)

ParseGetHostResponse parses an HTTP response from a GetHostWithResponse call

func (GetHostResponse) ContentType added in v0.4.0

func (r GetHostResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostResponse) Status

func (r GetHostResponse) Status() string

Status returns HTTPResponse.Status

func (GetHostResponse) StatusCode

func (r GetHostResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetHostsParams added in v0.4.0

type GetHostsParams struct {
	// Page pagination page number
	Page *int `form:"page,omitempty" json:"page,omitempty"`

	// PerPage Number of records to return
	PerPage *int `form:"per_page,omitempty" json:"per_page,omitempty"`
}

GetHostsParams defines parameters for GetHosts.

type GetHostsResponse added in v0.4.0

type GetHostsResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *[]Host
}

func ParseGetHostsResponse added in v0.4.0

func ParseGetHostsResponse(rsp *http.Response) (*GetHostsResponse, error)

ParseGetHostsResponse parses an HTTP response from a GetHostsWithResponse call

func (GetHostsResponse) ContentType added in v0.4.0

func (r GetHostsResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetHostsResponse) Status added in v0.4.0

func (r GetHostsResponse) Status() string

Status returns HTTPResponse.Status

func (GetHostsResponse) StatusCode added in v0.4.0

func (r GetHostsResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetJobResponse

type GetJobResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *Job
}

func ParseGetJobResponse

func ParseGetJobResponse(rsp *http.Response) (*GetJobResponse, error)

ParseGetJobResponse parses an HTTP response from a GetJobWithResponse call

func (GetJobResponse) ContentType added in v0.4.0

func (r GetJobResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (GetJobResponse) Status

func (r GetJobResponse) Status() string

Status returns HTTPResponse.Status

func (GetJobResponse) StatusCode

func (r GetJobResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type Host

type Host struct {
	AuthorsCount      *int       `json:"authors_count,omitempty"`
	IconURL           *string    `json:"icon_url,omitempty"`
	IssuesCount       *int       `json:"issues_count,omitempty"`
	Kind              *string    `json:"kind,omitempty"`
	LastSyncedAt      *time.Time `json:"last_synced_at,omitempty"`
	Name              *string    `json:"name,omitempty"`
	PullRequestsCount *int       `json:"pull_requests_count,omitempty"`
	RepositoriesCount *int       `json:"repositories_count,omitempty"`
	URL               *string    `json:"url,omitempty"`
}

Host defines model for Host.

type HttpRequestDoer

type HttpRequestDoer interface {
	Do(req *http.Request) (*http.Response, error)
}

Doer performs HTTP requests.

The standard http.Client implements this interface.

type Issue

type Issue struct {
	Assignees         []string   `json:"assignees,omitempty"`
	AuthorAssociation *string    `json:"author_association,omitempty"`
	ClosedAt          *time.Time `json:"closed_at,omitempty"`
	Comments          *int       `json:"comments,omitempty"`
	CommentsCount     *int       `json:"comments_count,omitempty"`
	CreatedAt         *time.Time `json:"created_at,omitempty"`
	HTMLURL           *string    `json:"html_url,omitempty"`
	Labels            []string   `json:"labels,omitempty"`
	Locked            *bool      `json:"locked,omitempty"`
	MergedAt          *time.Time `json:"merged_at,omitempty"`
	NodeID            *string    `json:"node_id,omitempty"`
	Number            *int       `json:"number,omitempty"`
	PullRequest       *bool      `json:"pull_request,omitempty"`
	State             *string    `json:"state,omitempty"`
	StateReason       *string    `json:"state_reason,omitempty"`
	TimeToClose       *int       `json:"time_to_close,omitempty"`
	Title             *string    `json:"title,omitempty"`
	UpdatedAt         *time.Time `json:"updated_at,omitempty"`
	URL               *string    `json:"url,omitempty"`
	User              *string    `json:"user,omitempty"`
	UUID              *int       `json:"uuid,omitempty"`
}

Issue defines model for Issue.

type Job

type Job struct {
	CreatedAt *time.Time             `json:"created_at,omitempty"`
	ID        *int                   `json:"id,omitempty"`
	Results   map[string]interface{} `json:"results,omitempty"`
	SidekiqID *string                `json:"sidekiq_id,omitempty"`
	Status    *string                `json:"status,omitempty"`
	UpdatedAt *time.Time             `json:"updated_at,omitempty"`
	URL       *string                `json:"url,omitempty"`
}

Job defines model for Job.

type LabelCount

type LabelCount struct {
	Count     *int    `json:"count,omitempty"`
	IssuesURL *string `json:"issues_url,omitempty"`
	Label     *string `json:"label,omitempty"`
}

LabelCount defines model for LabelCount.

type MaintainerCount

type MaintainerCount struct {
	Count      *int    `json:"count,omitempty"`
	Maintainer *string `json:"maintainer,omitempty"`
	URL        *string `json:"url,omitempty"`
}

MaintainerCount defines model for MaintainerCount.

type Maintainers

type Maintainers struct {
	ActiveMaintainers []MaintainerCount `json:"active_maintainers,omitempty"`
	Login             *string           `json:"login,omitempty"`
	Maintainers       []MaintainerCount `json:"maintainers,omitempty"`
}

Maintainers defines model for Maintainers.

type Owner

type Owner struct {
	ActiveMaintainers                  []MaintainerCount        `json:"active_maintainers,omitempty"`
	AverageIssueCloseTime              *float32                 `json:"average_issue_close_time,omitempty"`
	AverageIssueCommentsCount          *float32                 `json:"average_issue_comments_count,omitempty"`
	AveragePullRequestCloseTime        *float32                 `json:"average_pull_request_close_time,omitempty"`
	AveragePullRequestCommentsCount    *float32                 `json:"average_pull_request_comments_count,omitempty"`
	IssueAuthorAssociationsCount       []AuthorAssociationCount `json:"issue_author_associations_count,omitempty"`
	IssueAuthors                       []AuthorCount            `json:"issue_authors,omitempty"`
	IssueLabelsCount                   []LabelCount             `json:"issue_labels_count,omitempty"`
	IssueRepos                         []RepoCount              `json:"issue_repos,omitempty"`
	IssuesCount                        *int                     `json:"issues_count,omitempty"`
	Login                              *string                  `json:"login,omitempty"`
	Maintainers                        []MaintainerCount        `json:"maintainers,omitempty"`
	MergedPullRequestsCount            *int                     `json:"merged_pull_requests_count,omitempty"`
	PullRequestAuthorAssociationsCount []AuthorAssociationCount `json:"pull_request_author_associations_count,omitempty"`
	PullRequestAuthors                 []AuthorCount            `json:"pull_request_authors,omitempty"`
	PullRequestLabelsCount             []LabelCount             `json:"pull_request_labels_count,omitempty"`
	PullRequestRepos                   []RepoCount              `json:"pull_request_repos,omitempty"`
	PullRequestsCount                  *int                     `json:"pull_requests_count,omitempty"`
}

Owner defines model for Owner.

type OwnerSummary

type OwnerSummary struct {
	Login             *string `json:"login,omitempty"`
	OwnerURL          *string `json:"owner_url,omitempty"`
	RepositoriesCount *int    `json:"repositories_count,omitempty"`
}

OwnerSummary defines model for OwnerSummary.

type RepoCount

type RepoCount struct {
	Count      *int    `json:"count,omitempty"`
	Repository *string `json:"repository,omitempty"`
	URL        *string `json:"url,omitempty"`
}

RepoCount defines model for RepoCount.

type RepositoriesLookupParams

type RepositoriesLookupParams struct {
	// URL The URL of the repository to lookup
	URL string `form:"url" json:"url"`
}

RepositoriesLookupParams defines parameters for RepositoriesLookup.

type RepositoriesLookupResponse

type RepositoriesLookupResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	// JSON200 the response for an HTTP 200 `application/json` response
	JSON200 *Repository
}

func ParseRepositoriesLookupResponse

func ParseRepositoriesLookupResponse(rsp *http.Response) (*RepositoriesLookupResponse, error)

ParseRepositoriesLookupResponse parses an HTTP response from a RepositoriesLookupWithResponse call

func (RepositoriesLookupResponse) ContentType added in v0.4.0

func (r RepositoriesLookupResponse) ContentType() string

ContentType is a convenience method to retrieve the Content-Type value from the HTTP response headers

func (RepositoriesLookupResponse) Status

Status returns HTTPResponse.Status

func (RepositoriesLookupResponse) StatusCode

func (r RepositoriesLookupResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type Repository

type Repository struct {
	AvgCommentsPerIssue               *float32   `json:"avg_comments_per_issue,omitempty"`
	AvgCommentsPerPullRequest         *float32   `json:"avg_comments_per_pull_request,omitempty"`
	AvgTimeToCloseIssue               *float32   `json:"avg_time_to_close_issue,omitempty"`
	AvgTimeToClosePullRequest         *float32   `json:"avg_time_to_close_pull_request,omitempty"`
	BotIssuesCount                    *int       `json:"bot_issues_count,omitempty"`
	BotPullRequestsCount              *int       `json:"bot_pull_requests_count,omitempty"`
	CreatedAt                         *time.Time `json:"created_at,omitempty"`
	FullName                          *string    `json:"full_name,omitempty"`
	HTMLURL                           *string    `json:"html_url,omitempty"`
	IssueAuthorsCount                 *int       `json:"issue_authors_count,omitempty"`
	IssuesClosedCount                 *int       `json:"issues_closed_count,omitempty"`
	IssuesCount                       *int       `json:"issues_count,omitempty"`
	IssuesURL                         *string    `json:"issues_url,omitempty"`
	LastSyncedAt                      *time.Time `json:"last_synced_at,omitempty"`
	MergedPullRequestsCount           *int       `json:"merged_pull_requests_count,omitempty"`
	PastYearAvgCommentsPerIssue       *float32   `json:"past_year_avg_comments_per_issue,omitempty"`
	PastYearAvgCommentsPerPullRequest *float32   `json:"past_year_avg_comments_per_pull_request,omitempty"`
	PastYearAvgTimeToCloseIssue       *float32   `json:"past_year_avg_time_to_close_issue,omitempty"`
	PastYearAvgTimeToClosePullRequest *float32   `json:"past_year_avg_time_to_close_pull_request,omitempty"`
	PastYearBotIssuesCount            *int       `json:"past_year_bot_issues_count,omitempty"`
	PastYearBotPullRequestsCount      *int       `json:"past_year_bot_pull_requests_count,omitempty"`
	PastYearIssueAuthorsCount         *int       `json:"past_year_issue_authors_count,omitempty"`
	PastYearIssuesClosedCount         *int       `json:"past_year_issues_closed_count,omitempty"`
	PastYearIssuesCount               *int       `json:"past_year_issues_count,omitempty"`
	PastYearMergedPullRequestsCount   *int       `json:"past_year_merged_pull_requests_count,omitempty"`
	PastYearPullRequestAuthorsCount   *int       `json:"past_year_pull_request_authors_count,omitempty"`
	PastYearPullRequestsClosedCount   *int       `json:"past_year_pull_requests_closed_count,omitempty"`
	PastYearPullRequestsCount         *int       `json:"past_year_pull_requests_count,omitempty"`
	PullRequestAuthorsCount           *int       `json:"pull_request_authors_count,omitempty"`
	PullRequestsClosedCount           *int       `json:"pull_requests_closed_count,omitempty"`
	PullRequestsCount                 *int       `json:"pull_requests_count,omitempty"`
	Status                            *string    `json:"status,omitempty"`
	UpdatedAt                         *time.Time `json:"updated_at,omitempty"`
}

Repository defines model for Repository.

type RequestEditorFn

type RequestEditorFn func(ctx context.Context, req *http.Request) error

RequestEditorFn is the function signature for the RequestEditor callback function

Jump to